@@ -8,7 +8,7 @@ use App::Netdisco::Util::Device 'delete_device';
 
 register_worker({ phase => 'check' }, sub {
   return Status->error('Missing device (-d).')
-    unless defined shift->device;
+    unless shift->device;
   return Status->done('Delete is able to run');
 });
 
